mTexture = GUI_PickTexture("flash","Flame  Texture 1");
mColor1 = GUI_ColorPick(
254,255,255,255,
   "Flame/ Color1");
mColor2 = GUI_ColorPick(
255,255,200,200,   "Flame/ Color2");
mColor3 = GUI_ColorPick(
255,200,100,100,
   "Flame/ Color3");
mColor1Age_ms = 100;
mColor2Age_ms = 180;
mColor3Age_ms = 190;
mExpireTime = 200;
mStopEmitAt = 100;
mEmitSpeed = 10;
mMaxParticles = 200;
mIniScale = 0.1;
mScaleSpeed = 9;
mMaxSpeed = 30;
mMaxSpinSpeed = 1;
mBlendMode = kBlendAdditiveAlpha;

-- ------------------------------------------------------------
-- Define our particle characteristics

pVelocity = Allocate(2) ; -- Allocate a Vec2 velocity member
pAge = Allocate(1) ; -- Allocate a TReal age member
pSpin = Allocate(1); -- Allocate a TReal spin member
pSpinSpeed = Allocate(1); -- Allocate a TReal spin member

-- Set the particle texture
SetTexture(mTexture);

-- Set the blend mode
SetBlendMode(mBlendMode);

-- LAST, we set the total number of particles in the particle
-- system. This doesn't 'create' the particles, but rather
-- allocates a block of 'dead' particles that can be created
-- below.
SetNumParticles(mMaxParticles);

-- ------------------------------------------------------------
-- Initialization rules.
-- 
-- The following rules define how particles are created.
--
-- Any parameter below in initialization or animation rules that 
-- is a scalar, Color(), or Vec2() can alternaly take a function 
-- that returns the same type--and most functions can take any type
-- and will return that same type. The exception is any function
-- that's expecting a scalar in certain parameter positions.

-- Define dLocus for FluidFX; in the game it's defined in 
-- swarm.cpp as a data source, and it gets the mouse position.
if not dLocus then
   dLocus= Vec2(0,0) ; 
end

-- Pick a position randomly, within a range of values.
-- dLocus is defined in swarm.cpp and added to the random
-- range
pPosition:Init( dLocus );

-- Pick a velocity within a range
pVelocity:Init( fRange( Vec2(-mMaxSpeed,-mMaxSpeed), Vec2(mMaxSpeed,mMaxSpeed) ) );

-- Start scale at 0.5
pScale:Init( mIniScale );

-- Start age as 0 milliseconds
pAge:Init(0);

-- Start initial rotation as a random angle
pSpin:Init( fRange( 0, 2*3.1415927 ) );

-- Start spin velocity random from -10 to 10
pSpinSpeed:Init( fRange( -mMaxSpinSpeed, mMaxSpinSpeed ) );

-- ------------------------------------------------------------
-- Particle Parameter Animation Functions
--
-- The following rules define how particles animate.
-- Each rule is applied on each frame of animation.

-- Add velocity scaled by time to position
pPosition:Anim( pPosition + fTimeScale(pVelocity) );

-- Add 1/second to scale
pScale:Anim( pScale + fTimeScale(mScaleSpeed) );

-- Add gravity scaled by time to velocity
--pVelocity:Anim( pVelocity + fTimeScale(Vec2(0,250)) );

-- Fade (using age) from white to yellow to black. Assumes
-- the first parameter is a number of elapsed milliseconds,
-- though can work to linearly interpolate using first 
-- scalar parameter between any value types.
mColor1 = Color(1,1,1,1);
pColor:Init(mColor1);
pColor:Anim( 
   fFade( pAge,
      Color(1,1,1,1),mColor1Age_ms,
     Color(1,1,0.784,0.784),mColor2Age_ms,
     Color(1,0.784,0.392,0.392),mColor3Age_ms,
      Color(0,0,0,0.5) ) -- to final color
   );

-- Spin by pSpinSpeed scaled by time
pSpin:Anim( pSpin + fTimeScale( pSpinSpeed ) );

-- Set the particle's "Up" vector to the current user variable
-- "pSpin"
pUp:Anim( f2dRotation( pSpin ) );

-- Age the particle using age function
pAge:Anim( pAge+fAge() );

-- General Anim functions
-- Expire particles over 700 ms old
Anim( fExpire( fGreater(pAge,mExpireTime) ) );

-- ------------------------------------------------------------
-- Create initial particles (optional)
-- CreateParticles( 1 );

-- ------------------------------------------------------------
time_ms=0;
-- A function to run as we're executing
-- seconds - how many seconds have elapsed
function Update(seconds)
   time_ms = time_ms + seconds*1000;
   if time_ms<mStopEmitAt then
        CreateParticles( seconds * mEmitSpeed );
   end
   if time_ms>(mStopEmitAt+mExpireTime) then
        Done();
   end
end
